==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Wyczyść wszystko</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centrum powiadomień</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Wyczyść wszystko</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Odepnij</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Przypnij</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ustawienia powiadomień</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Właśnie teraz</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minut temu</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 godzinę temu</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 godzin temu</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Wczoraj </translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Wyczyść wszystko</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centrum powiadomień</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Wyczyść wszystko</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Odepnij</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Przypnij</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ustawienia powiadomień</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Właśnie teraz</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minut temu</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 godzinę temu</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 godzin temu</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Wczoraj </translation>
    </message>
</context>
</TS>
